==> haskell-unixutils-1.54.2-19-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unixutils.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 Unixutils
version:              1.54.2
visibility:           public
id:                   Unixutils-1.54.2-3UwKfNryGvFC04GDT8A2ni
key:                  Unixutils-1.54.2-3UwKfNryGvFC04GDT8A2ni
license:              BSD-3-Clause
maintainer:           jeremy@n-heptane.com
author:               Jeremy Shaw, David Fox
homepage:             https://github.com/seereason/haskell-unixutils.git
synopsis:
    A crude interface between Haskell and Unix-like operating systems

description:
    A collection of useful and mildly useful functions that you might
    expect to find in System.* which a heavy bias towards Unix-type operating systems.

category:             System
abi:                  20e43855d375ab5f72c6098afa8c9405
exposed:              True
exposed-modules:
    System.Unix.Chroot System.Unix.Crypt System.Unix.Directory
    System.Unix.FilePath System.Unix.Files System.Unix.KillByCwd
    System.Unix.Misc System.Unix.Mount System.Unix.SpecialDevice

import-dirs:          /usr/lib/ghc-9.0.1/site-local/Unixutils-1.54.2
library-dirs:         /usr/lib/ghc-9.0.1/site-local/Unixutils-1.54.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/Unixutils-1.54.2
hs-libraries:         HSUnixutils-1.54.2-3UwKfNryGvFC04GDT8A2ni
extra-libraries:      crypt
depends:
    base-4.15.0.0 bytestring-0.10.12.1 directory-1.3.6.1
    exceptions-0.10.4 filepath-1.4.2.1 mtl-2.2.2 process-1.6.11.0
    process-extras-0.7.4-3B9UqfYzA3uBhNazZjIJ6F
    pureMD5-2.1.3-2OJdHHCiW1e5yAxy0Hl5vD
    regex-tdfa-1.3.1.1-8KBKH3EsotI2v3BWqoG8PB unix-2.7.2.2
    zlib-0.6.2.3-IBsa4ASfS3OGtPlbWVfkI3

haddock-interfaces:   /usr/share/doc/haskell-unixutils/html/Unixutils.haddock
haddock-html:         /usr/share/doc/haskell-unixutils/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unixutils-1.54.2-21-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unixutils.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 Unixutils
version:              1.54.2
visibility:           public
id:                   Unixutils-1.54.2-58bbXehm3psHGNeOeVz8d0
key:                  Unixutils-1.54.2-58bbXehm3psHGNeOeVz8d0
license:              BSD-3-Clause
maintainer:           jeremy@n-heptane.com
author:               Jeremy Shaw, David Fox
homepage:             https://github.com/seereason/haskell-unixutils.git
synopsis:
    A crude interface between Haskell and Unix-like operating systems

description:
    A collection of useful and mildly useful functions that you might
    expect to find in System.* which a heavy bias towards Unix-type operating systems.

category:             System
abi:                  f7afc7132c2672838ed68340eb46e1e3
exposed:              True
exposed-modules:
    System.Unix.Chroot System.Unix.Crypt System.Unix.Directory
    System.Unix.FilePath System.Unix.Files System.Unix.KillByCwd
    System.Unix.Misc System.Unix.Mount System.Unix.SpecialDevice

import-dirs:          /usr/lib/ghc-9.0.1/site-local/Unixutils-1.54.2
library-dirs:         /usr/lib/ghc-9.0.1/site-local/Unixutils-1.54.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/Unixutils-1.54.2
hs-libraries:         HSUnixutils-1.54.2-58bbXehm3psHGNeOeVz8d0
extra-libraries:      crypt
depends:
    base-4.15.0.0 bytestring-0.10.12.1 directory-1.3.6.1
    exceptions-0.10.4 filepath-1.4.2.1 mtl-2.2.2 process-1.6.11.0
    process-extras-0.7.4-D2cz2DPsfYE8esD6cOYaeh
    pureMD5-2.1.3-2OJdHHCiW1e5yAxy0Hl5vD
    regex-tdfa-1.3.1.1-8KBKH3EsotI2v3BWqoG8PB unix-2.7.2.2
    zlib-0.6.2.3-2cqIXBVKfBeDkv2RdIbETX

haddock-interfaces:   /usr/share/doc/haskell-unixutils/html/Unixutils.haddock
haddock-html:         /usr/share/doc/haskell-unixutils/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
